@@ -66,19 +66,26 @@ struct Cmd
 	  works_without_dbus(works_without_dbus), needs_snapper(needs_snapper)
     {}
 
+    Cmd(const string& name, const vector<string>& aliases, cmd_func_t cmd_func,
+	help_func_t help_func, bool works_without_dbus, bool needs_snapper)
+	: name(name), aliases(aliases), cmd_func(cmd_func), help_func(help_func),
+	  works_without_dbus(works_without_dbus), needs_snapper(needs_snapper)
+    {}
+
     const string name;
+    const vector<string> aliases;
     const cmd_func_t cmd_func;
     const help_func_t help_func;
     const bool works_without_dbus;
     const bool needs_snapper;
 };
 
-list<Cmd> cmds;
-
 GetOpts getopts;
 
 bool quiet = false;
 bool verbose = false;
+bool utc = false;
+bool iso = false;
 string config_name = "root";
 bool no_dbus = false;
 
@@ -440,7 +447,7 @@ command_list(DBus::Connection* conn, Snapper* snapper)
 		    row.add(toString(it1->getType()));
 		    row.add(decString(it1->getNum()));
 		    row.add(it1->getType() == POST ? decString(it1->getPreNum()) : "");
-		    row.add(it1->isCurrent() ? "" : datetime(it1->getDate(), false, false));
+		    row.add(it1->isCurrent() ? "" : datetime(it1->getDate(), utc, iso));
 		    row.add(username(it1->getUid()));
 		    row.add(it1->getCleanup());
 		    row.add(it1->getDescription());
@@ -457,7 +464,7 @@ command_list(DBus::Connection* conn, Snapper* snapper)
 		    row.add(toString(it1->getType()));
 		    row.add(decString(it1->getNum()));
 		    row.add(it1->getType() == POST ? decString(it1->getPreNum()) : "");
-		    row.add(it1->isCurrent() ? "" : datetime(it1->getDate(), false, false));
+		    row.add(it1->isCurrent() ? "" : datetime(it1->getDate(), utc, iso));
 		    row.add(username(it1->getUid()));
 		    row.add(it1->getCleanup());
 		    row.add(it1->getDescription());
@@ -488,7 +495,7 @@ command_list(DBus::Connection* conn, Snapper* snapper)
 
 		    TableRow row;
 		    row.add(decString(it1->getNum()));
-		    row.add(it1->isCurrent() ? "" : datetime(it1->getDate(), false, false));
+		    row.add(it1->isCurrent() ? "" : datetime(it1->getDate(), utc, iso));
 		    row.add(username(it1->getUid()));
 		    row.add(it1->getDescription());
 		    row.add(show_userdata(it1->getUserdata()));
@@ -505,7 +512,7 @@ command_list(DBus::Connection* conn, Snapper* snapper)
 
 		    TableRow row;
 		    row.add(decString(it1->getNum()));
-		    row.add(it1->isCurrent() ? "" : datetime(it1->getDate(), false, false));
+		    row.add(it1->isCurrent() ? "" : datetime(it1->getDate(), utc, iso));
 		    row.add(username(it1->getUid()));
 		    row.add(it1->getDescription());
 		    row.add(show_userdata(it1->getUserdata()));
@@ -541,8 +548,8 @@ command_list(DBus::Connection* conn, Snapper* snapper)
 		    TableRow row;
 		    row.add(decString(it1->getNum()));
 		    row.add(decString(it2->getNum()));
-		    row.add(datetime(it1->getDate(), false, false));
-		    row.add(datetime(it2->getDate(), false, false));
+		    row.add(datetime(it1->getDate(), utc, iso));
+		    row.add(datetime(it2->getDate(), utc, iso));
 		    row.add(it1->getDescription());
 		    row.add(show_userdata(it1->getUserdata()));
 		    table.add(row);
@@ -563,8 +570,8 @@ command_list(DBus::Connection* conn, Snapper* snapper)
 		    TableRow row;
 		    row.add(decString(it1->getNum()));
 		    row.add(decString(it2->getNum()));
-		    row.add(datetime(it1->getDate(), false, false));
-		    row.add(datetime(it2->getDate(), false, false));
+		    row.add(datetime(it1->getDate(), utc, iso));
+		    row.add(datetime(it2->getDate(), utc, iso));
 		    row.add(it1->getDescription());
 		    row.add(show_userdata(it1->getUserdata()));
 		    table.add(row);
@@ -1263,22 +1270,25 @@ command_rollback(DBus::Connection* conn, Snapper* snapper)
 	exit(EXIT_FAILURE);
     }
 
-    unsigned int tmp;
+    unsigned int num2;
 
     if (getopts.numArgs() == 0)
     {
-	tmp = command_create_single_xsnapshot_of_default(*conn, config_name, true, description,
-							 cleanup, userdata);
+	command_create_single_xsnapshot_of_default(*conn, config_name, true, description, cleanup,
+						   userdata);
+
+	num2 = command_create_single_xsnapshot_v2(*conn, config_name, 0, false, description,
+						  cleanup, userdata);
     }
     else
     {
-	tmp = read_num(getopts.popArg());
+	unsigned int tmp = read_num(getopts.popArg());
 
 	command_create_single_xsnapshot(*conn, config_name, description, cleanup, userdata);
-    }
 
-    unsigned int num2 = command_create_single_xsnapshot_v2(*conn, config_name, tmp, false,
-							   description, cleanup, userdata);
+	num2 = command_create_single_xsnapshot_v2(*conn, config_name, tmp, false,
+						  description, cleanup, userdata);
+    }
 
     filesystem->setDefault(num2);
 
@@ -1443,7 +1453,7 @@ usage()
 void help() __attribute__ ((__noreturn__));
 
 void
-help()
+help(const list<Cmd>& cmds)
 {
     getopts.parse("help", GetOpts::no_options);
     if (getopts.hasArgs())
@@ -1458,6 +1468,8 @@ help()
     cout << _("    Global options:") << endl
 	 << _("\t--quiet, -q\t\t\tSuppress normal output.") << endl
 	 << _("\t--verbose, -v\t\t\tIncrease verbosity.") << endl
+	 << _("\t--utc\t\t\t\tDisplay dates and times in UTC.") << endl
+	 << _("\t--iso\t\t\t\tDisplay dates and times in ISO format.") << endl
 	 << _("\t--table-style, -t <style>\tTable style (integer).") << endl
 	 << _("\t--config, -c <name>\t\tSet name of config to use.") << endl
 	 << _("\t--no-dbus\t\t\tOperate without DBus.") << endl
@@ -1479,32 +1491,36 @@ main(int argc, char** argv)
     setLogDo(&log_do);
     setLogQuery(&log_query);
 
-    cmds.push_back(Cmd("list-configs", command_list_configs, help_list_configs, true, false));
-    cmds.push_back(Cmd("create-config", command_create_config, help_create_config, true, false));
-    cmds.push_back(Cmd("delete-config", command_delete_config, help_delete_config, true, false));
-    cmds.push_back(Cmd("get-config", command_get_config, help_get_config, true, false));
-    cmds.push_back(Cmd("set-config", command_set_config, help_set_config, true, true));
-    cmds.push_back(Cmd("list", command_list, help_list, true, true));
-    cmds.push_back(Cmd("create", command_create, help_create, false, true));
-    cmds.push_back(Cmd("modify", command_modify, help_modify, false, true));
-    cmds.push_back(Cmd("delete", command_delete, help_delete, false, true));
-    cmds.push_back(Cmd("mount", command_mount, help_mount, true, true));
-    cmds.push_back(Cmd("umount", command_umount, help_umount, true, true));
-    cmds.push_back(Cmd("status", command_status, help_status, false, true));
-    cmds.push_back(Cmd("diff", command_diff, help_diff, false, true));
+    const list<Cmd> cmds = {
+	Cmd("list-configs", command_list_configs, help_list_configs, true, false),
+	Cmd("create-config", command_create_config, help_create_config, true, false),
+	Cmd("delete-config", command_delete_config, help_delete_config, true, false),
+	Cmd("get-config", command_get_config, help_get_config, true, false),
+	Cmd("set-config", command_set_config, help_set_config, true, true),
+	Cmd("list", { "ls" }, command_list, help_list, true, true),
+	Cmd("create", command_create, help_create, false, true),
+	Cmd("modify", command_modify, help_modify, false, true),
+	Cmd("delete", { "remove", "rm" }, command_delete, help_delete, false, true),
+	Cmd("mount", command_mount, help_mount, true, true),
+	Cmd("umount", command_umount, help_umount, true, true),
+	Cmd("status", command_status, help_status, false, true),
+	Cmd("diff", command_diff, help_diff, false, true),
 #ifdef ENABLE_XATTRS
-    cmds.push_back(Cmd("xadiff", command_xa_diff, help_xa_diff, false, true));
+	Cmd("xadiff", command_xa_diff, help_xa_diff, false, true),
 #endif
-    cmds.push_back(Cmd("undochange", command_undo, help_undo, false, true));
+	Cmd("undochange", command_undo, help_undo, false, true),
 #ifdef ENABLE_ROLLBACK
-    cmds.push_back(Cmd("rollback", command_rollback, help_rollback, false, true));
+	Cmd("rollback", command_rollback, help_rollback, false, true),
 #endif
-    cmds.push_back(Cmd("cleanup", command_cleanup, help_cleanup, false, true));
-    cmds.push_back(Cmd("debug", command_debug, help_debug, false, false));
+	Cmd("cleanup", command_cleanup, help_cleanup, false, true),
+	Cmd("debug", command_debug, help_debug, false, false)
+    };
 
     const struct option options[] = {
 	{ "quiet",		no_argument,		0,	'q' },
 	{ "verbose",		no_argument,		0,	'v' },
+	{ "utc",		no_argument,		0,	0 },
+	{ "iso",		no_argument,		0,	0 },
 	{ "table-style",	required_argument,	0,	't' },
 	{ "config",		required_argument,	0,	'c' },
 	{ "no-dbus",		no_argument,		0,	0 },
@@ -1525,6 +1541,12 @@ main(int argc, char** argv)
     if ((opt = opts.find("verbose")) != opts.end())
 	verbose = true;
 
+    if ((opt = opts.find("utc")) != opts.end())
+	utc = true;
+
+    if ((opt = opts.find("iso")) != opts.end())
+	iso = true;
+
     if ((opt = opts.find("table-style")) != opts.end())
     {
 	unsigned int s;
@@ -1552,7 +1574,7 @@ main(int argc, char** argv)
 
     if ((opt = opts.find("help")) != opts.end())
     {
-	help();
+	help(cmds);
     }
 
     if (!getopts.hasArgs())
@@ -1565,7 +1587,7 @@ main(int argc, char** argv)
     const char* command = getopts.popArg();
 
     list<Cmd>::const_iterator cmd = cmds.begin();
-    while (cmd != cmds.end() && cmd->name != command)
+    while (cmd != cmds.end() && (cmd->name != command && !contains(cmd->aliases, command)))
 	++cmd;
 
     if (cmd == cmds.end())
