@@ -20,6 +20,8 @@
  */
 
 
+#include "config.h"
+
 #include <snapper/Log.h>
 #include <snapper/SnapperTmpl.h>
 #include <snapper/AsciiFile.h>
@@ -270,7 +272,7 @@ Client::introspect(DBus::Connection& conn, DBus::Message& msg)
 	"    <method name='CreateSingleSnapshotV2'>\n"
 	"      <arg name='config-name' type='s' direction='in'/>\n"
 	"      <arg name='parent-number' type='u' direction='in'/>\n"
-	"      <arg name='read-only' type 'b' direction='in'/>\n"
+	"      <arg name='read-only' type='b' direction='in'/>\n"
 	"      <arg name='description' type='s' direction='in'/>\n"
 	"      <arg name='cleanup' type='s' direction='in'/>\n"
 	"      <arg name='userdata' type='a{ss}' direction='in'/>\n"
@@ -279,7 +281,7 @@ Client::introspect(DBus::Connection& conn, DBus::Message& msg)
 
 	"    <method name='CreateSingleSnapshotOfDefault'>\n"
 	"      <arg name='config-name' type='s' direction='in'/>\n"
-	"      <arg name='read-only' type 'b' direction='in'/>\n"
+	"      <arg name='read-only' type='b' direction='in'/>\n"
 	"      <arg name='description' type='s' direction='in'/>\n"
 	"      <arg name='cleanup' type='s' direction='in'/>\n"
 	"      <arg name='userdata' type='a{ss}' direction='in'/>\n"
@@ -1343,6 +1345,27 @@ Client::debug(DBus::Connection& conn, DBus::Message& msg) const
 	hoho << s.str();
     }
 
+    hoho << "compile options:";
+    hoho << "  VERSION " VERSION;
+#ifdef ENABLE_BTRFS
+    hoho << "  ENABLE_BTRFS";
+#endif
+#ifdef ENABLE_LVM
+    hoho << "  ENABLE_LVM";
+#endif
+#ifdef ENABLE_EXT4
+    hoho << "  ENABLE_EXT4";
+#endif
+#ifdef ENABLE_XATTRS
+    hoho << "  ENABLE_XATTRS";
+#endif
+#ifdef ENABLE_ROLLBACK
+    hoho << "  ENABLE_ROLLBACK";
+#endif
+#ifdef HAVE_LIBBTRFS
+    hoho << "  HAVE_LIBBTRFS";
+#endif
+
     hoho.close_array();
 
     conn.send(reply);
